@@ -29,6 +29,7 @@ DashboardId = TypeVar('DashboardId', bound=str)
 BucketId = TypeVar('BucketId', bound=str)
 IndicatorId = TypeVar('IndicatorId', bound=str)
 InspectionId = TypeVar('InspectionId', bound=str)
-NavigationId = TypeVar('NavigationId', bound=str)
+AchievementId = TypeVar('AchievementId', bound=str)
+ObjectiveAnalysisId = TypeVar('ObjectiveAnalysisId', bound=str)
 
 PatId = TypeVar('PatId', bound=str)
